@@ -8,13 +8,9 @@ for my $word (@words) {
     my $tf = Text::Fuzzy->new ($word);
     $tf->no_exact (0);
     my $nearest = $tf->nearest (\@words);
-    if ($nearest >= 0) {
-	print "With exact, nearest to $word is $words[$nearest]\n";
-    }
+    print "With exact, nearest to $word is $words[$nearest]\n";
     # Make "$word" not match itself.
     $tf->no_exact (1);
     my $nearest = $tf->nearest (\@words);
-    if ($nearest >= 0) {
-	print "Without exact, nearest to $word is $words[$nearest]\n";
-    }
+    print "Without exact, nearest to $word is $words[$nearest]\n";
 }
